<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Gdpr_tools
 * @subpackage Gdpr_tools/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Gdpr_tools
 * @subpackage Gdpr_tools/includes
 * @author     Your Name <email@example.com>
 */
class Gdpr_tools {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Gdpr_tools_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $gdpr_tools    The string used to uniquely identify this plugin.
	 */
	protected $gdpr_tools;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */

	protected $settings;

	public function __construct() {
		if ( defined( 'GDPR_TOOLS_VERSION' ) ) {
			$this->version = GDPR_TOOLS_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->gdpr_tools = 'gdpr-tools';

		$this->settings = get_option('gdpr-tools-settings');

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();
		
	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Gdpr_tools_Loader. Orchestrates the hooks of the plugin.
	 * - Gdpr_tools_i18n. Defines internationalization functionality.
	 * - Gdpr_tools_Admin. Defines all hooks for the admin area.
	 * - Gdpr_tools_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-gdpr-tools-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-gdpr-tools-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-gdpr-tools-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-gdpr-tools-public.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-gdpr-tools-helper.php';

		$this->loader = new Gdpr_tools_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Gdpr_tools_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Gdpr_tools_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Gdpr_tools_Admin( $this->get_gdpr_tools(), $this->get_version(), $this->settings  );
		$this->loader->add_action( 'admin_menu', $plugin_admin, 'admin_menu'  );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
		$this->loader->add_action( 'admin_init', $plugin_admin, 'admin_init'  );
		$this->loader->add_action( 'wp_ajax_gdpr_tools_save_settings', $plugin_admin, 'save_settings'  );
		$this->loader->add_action( 'wp_ajax_gdpr_tools_remove_logs', $plugin_admin, 'remove_logs'  );
		
		$this->loader->add_action( 'edit_user_profile', $plugin_admin, 'edit_user_profile', PHP_INT_MAX, 1 );
		$this->loader->add_action( 'edit_user_profile_update', $plugin_admin, 'update_profile_fields' );


		$this->loader->add_action( 'admin_init', $plugin_admin, 'save_user_profile', 50 );
		$this->loader->add_action( 'admin_init', $plugin_admin, 'save_user_profile', 50 );
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {
		$plugin_public = new Gdpr_tools_Public( $this->get_gdpr_tools(), $this->get_version(), $this->settings  );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts', 11 );
		$this->loader->add_action( 'wp_footer', $plugin_public, 'footer', 10 );
		$this->loader->add_action( 'init', $plugin_public, 'init', 0 );
		$this->loader->add_action( 'wp_head', $plugin_public, 'header', 20 );
		if ( $this->settings['print_codes_in_header'] ){
			$this->loader->add_action( 'wp_head', $plugin_public, 'print_codes', 21 );
		}else{
			$this->loader->add_action( 'wp_footer', $plugin_public, 'print_codes', 11 );
		}

		$this->loader->add_action( 'wp_login', $plugin_public, 'wp_login', 10, 2 );
		$this->loader->add_action( 'wp_ajax_gdpr_tools_save_privacy_settings', $plugin_public, 'save_privacy_settings'  );
		$this->loader->add_action( 'wp_ajax_gdpr_tools_save_notice_shown', $plugin_public, 'save_notice_shown'  );

	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_gdpr_tools() {
		return $this->gdpr_tools;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Gdpr_tools_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
